'use strict';

const RSVP = require('rsvp');

module.exports = {
  description: 'Blueprint for @choiceform/ui-foundation',

  normalizeEntityName(entityName) {
    return entityName;
  },

  afterInstall: function(options) {
    const isAddon = options.project.isEmberCLIAddon();
    const targetName = isAddon ? 'addon' : 'app';

    this.ui.writeInfoLine(`Installing dependencies for ${targetName} ...`);
    this.ui.writeInfoLine(`正在为 ${targetName} 安装依赖...`);

    const dependencies = [
      // Until ember-auto-import is compatible with babel v7
      // this.addAddonToProject({
      //   name: 'ember-auto-import',
      //   blueprintOptions: { save: isAddon },
      // }),
      this.addAddonToProject({
        name: 'ember-cli-autoprefixer',
        blueprintOptions: { save: isAddon },
      }),
      this.addAddonToProject({
        name: 'ember-css-modules',
        blueprintOptions: { save: isAddon },
      }),
      this.addAddonToProject({
        name: 'ember-lifeline',
        blueprintOptions: { save: isAddon },
      }),
      this.addAddonToProject({ name: '@ember/optional-features' }),
      this.addAddonToProject({ name: 'ember-cli-template-lint' }),
      this.addAddonToProject({ name: 'ember-qunit-decorators' }),
      this.addPackagesToProject([
        { name: 'eslint-plugin-node' },
        { name: 'eslint-plugin-qunit' },
        { name: 'eslint-plugin-typescript' },
      ]),
    ];

    return RSVP.all(dependencies).then(() => {
      this.ui.writeLine(`For ${targetName} usage, please run:`);
      this.ui.writeLine(`用于 ${targetName}，请运行：`);
      this.ui.writeInfoLine(`ember generate foundation-for-${targetName}`);
    });
  },
};
